@@ -133,20 +133,6 @@ class SpatialAnalysis:
           if failCondition == '1':
               assert(False) #break out of code
       
-
-      # Removing GeoPy Errors and printing number of failed address fetches
-      for i in range(0, len(self.c)):
-          if self.c['Distance from Stadium (miles)'][i] > self.__radSize or self.c['Distance from Stadium (miles)'][i] == 0:
-              self.c['Distance from Stadium (miles)'][i] = np.nan
-              self.c['Region'][i] = np.nan
-              self.c['Latitude'][i] = np.nan
-              self.c['Longitude'][i] = np.nan
-              self.c['Is Outlier'][i] = np.nan
-      print('GeoPy failed to find', self.c['Distance from Stadium (miles)'].isna().sum(), 'Values.')
-      if (self.c['Distance from Stadium (miles)'].isna().sum() != 0):
-          print('For now, they have been set blank, which may have resulted in a statement below from the Pandas Library.')
-          print('To complete an accurate analysis, manually gather the Straight Line Distance and Region for each')
-      
       values = self.c[self.__ValueColumnName].values.tolist()
       values_float = []
       for i in range(0, len(values)):
@@ -164,6 +150,19 @@ class SpatialAnalysis:
           else:
               self.c.at[i, 'Is Outlier'] = False
       self.c.to_csv(self.__path, index=False)
+
+      # Removing GeoPy Errors and printing number of failed address fetches
+      for i in range(0, len(self.c)):
+          if self.c['Distance from Stadium (miles)'][i] > self.__radSize or self.c['Distance from Stadium (miles)'][i] == 0:
+              self.c['Distance from Stadium (miles)'][i] = np.nan
+              self.c['Region'][i] = np.nan
+              self.c['Latitude'][i] = np.nan
+              self.c['Longitude'][i] = np.nan
+              self.c['Is Outlier'][i] = np.nan
+      print('GeoPy failed to find', self.c['Distance from Stadium (miles)'].isna().sum(), 'Values.')
+      if (self.c['Distance from Stadium (miles)'].isna().sum() != 0):
+          print('For now, they have been set blank, which may have resulted in a statement below from the Pandas Library.')
+          print('To complete an accurate analysis, manually gather the Straight Line Distance and Region for each')
       
   ####################################################################################################################################
   ####################################################### MISC. FUNCTIONS ############################################################
@@ -251,6 +250,26 @@ class SpatialAnalysis:
                   if (Change > 0):
                       Change = ''.join((str(round((Change * 100), 2)),'%'))
                       print('BINGO!:', Change, 'for x value:', checks[j], 'for region', regions[i])
+
+  # REQUIRES: User does not cancel out with '1' input
+  # MODIFIES self.c pandas dataframe
+  # EFFECT: Deletes column from the .csv file that the user inputed to the SpatialAnalysis
+  # NOTE1: INTENDED USE IS TO UNDO CHANGES FOR TUTORIAL
+  def destroy_mods(self):
+      assert(input('This function will destroy additions to the .csv file. Enter 1 to confirm or any input to cancel: ') != '1')
+      del self.c['Is Outlier']
+      del self.c['Region']
+      del self.c['Distance from Stadium (miles)']
+      del self.c['Latitude']
+      del self.c['Longitude']
+      self.c.to_csv(self.__path, index=False)
+
+  # REQUUIRES: valid csv input
+  # MODIFIES: N/A
+  # EFFECT: if used in Colab / Jupyter a visual of the data will print
+  def printCSV(self):
+      print('if used in Colab / Jupyter a visual of the data will print')
+      self.c
     
   # REQUIRES: numeric input
   # MODIFIES: print / matplotlib output
